## 1.1.0

- Add support for fetching course assignments from Canvas
- Add support for pushing assignment scores to Canvas

## 1.0.1

- Add dependency on `typing` for python 3.4 support

## 1.0.0

- Add Canvas API
